diff --git a/src/ImageProcessor/ImageFactory.cs b/src/ImageProcessor/ImageFactory.cs
index 4278122e88..43b21998ab 100644
--- a/src/ImageProcessor/ImageFactory.cs
+++ b/src/ImageProcessor/ImageFactory.cs
@@ -323,34 +323,6 @@ namespace ImageProcessor
return this;
}
- ///
- /// Applies a Gaussian blur to the current image.
- ///
- ///
- /// The radius by which to blur the images pixels.
- /// Any integer between 0 and 100.
- ///
- ///
- /// The current instance of the class.
- ///
- public ImageFactory Blur(int radius)
- {
- if (this.ShouldProcess)
- {
- // Sanitize the input.
- if (radius > 100)
- {
- radius = 0;
- }
-
- GaussianBlur blur = new GaussianBlur { DynamicParameter = radius };
-
- this.Image = blur.ProcessImage(this);
- }
-
- return this;
- }
-
///
/// Constrains the current image, resizing it to fit within the given dimensions whilst keeping its aspect ratio.
///
diff --git a/src/ImageProcessor/Properties/AssemblyInfo.cs b/src/ImageProcessor/Properties/AssemblyInfo.cs
index 8d7e4a0988..175d0cb717 100644
--- a/src/ImageProcessor/Properties/AssemblyInfo.cs
+++ b/src/ImageProcessor/Properties/AssemblyInfo.cs
@@ -32,6 +32,6 @@ using System.Security;
//
// You can specify all the values or you can default the Build and Revision Numbers
// by using the '*' as shown below:
-[assembly: AssemblyVersion("1.8.1.0")]
-[assembly: AssemblyFileVersion("1.8.1.0")]
+[assembly: AssemblyVersion("1.8.1.1")]
+[assembly: AssemblyFileVersion("1.8.1.1")]
diff --git a/src/Nuget/ImageProcessor.1.8.1.1.nupkg.REMOVED.git-id b/src/Nuget/ImageProcessor.1.8.1.1.nupkg.REMOVED.git-id
new file mode 100644
index 0000000000..bcabe5ff24
--- /dev/null
+++ b/src/Nuget/ImageProcessor.1.8.1.1.nupkg.REMOVED.git-id
@@ -0,0 +1 @@
+247fa919ace01d934bd0a19d37587ad26195b33e
\ No newline at end of file
diff --git a/src/TestWebsites/NET45/Test_Website_NET45/Images/Thumbs.db.REMOVED.git-id b/src/TestWebsites/NET45/Test_Website_NET45/Images/Thumbs.db.REMOVED.git-id
deleted file mode 100644
index 60a8946afe..0000000000
--- a/src/TestWebsites/NET45/Test_Website_NET45/Images/Thumbs.db.REMOVED.git-id
+++ /dev/null
@@ -1 +0,0 @@
-5a5eaebf9a5eafe87321a87bf497baf7e2152653
\ No newline at end of file
diff --git a/src/ImageProcessor/Imaging/TextLayer.cs b/src/ImageProcessor/Imaging/TextLayer.cs
index df367eaa3a..ae72fd9ae3 100644
--- a/src/ImageProcessor/Imaging/TextLayer.cs
+++ b/src/ImageProcessor/Imaging/TextLayer.cs
@@ -1,9 +1,12 @@
-// -----------------------------------------------------------------------
+// --------------------------------------------------------------------------------------------------------------------
//
-// Copyright (c) James South.
-// Licensed under the Apache License, Version 2.0.
+// Copyright (c) James South.
+// Licensed under the Apache License, Version 2.0.
//
-// -----------------------------------------------------------------------
+//
+// Encapsulates the properties required to add a layer of text to an image.
+//
+// --------------------------------------------------------------------------------------------------------------------
namespace ImageProcessor.Imaging
{
@@ -20,7 +23,7 @@ namespace ImageProcessor.Imaging
{
#region Fields
///
- /// The colour to render the text.
+ /// The color to render the text.
///
private Color textColor = Color.Black;
@@ -32,7 +35,7 @@ namespace ImageProcessor.Imaging
///
/// The font style to render the text.
///
- private FontStyle fontStyle = FontStyle.Bold;
+ private FontStyle fontStyle = FontStyle.Regular;
///
/// The font size to render the text.
@@ -53,6 +56,9 @@ namespace ImageProcessor.Imaging
///
/// Gets or sets the Color to render the font.
+ ///
+ /// Defaults to black.
+ ///
///
public Color TextColor
{
@@ -67,6 +73,9 @@ namespace ImageProcessor.Imaging
///
/// Gets or sets the size of the font in pixels.
+ ///
+ /// Defaults to 48 pixels.
+ ///
///
public int FontSize
{
@@ -75,7 +84,10 @@ namespace ImageProcessor.Imaging
}
///
/// Gets or sets the FontStyle of the textlayer.
///
public FontStyle Style
{
@@ -84,7 +96,7 @@ namespace ImageProcessor.Imaging
}
///
- /// Gets or sets the Opacity of the textlayer.
+ /// Gets or sets the Opacity of the text layer.
///
public int Opacity
{
@@ -102,7 +114,7 @@ namespace ImageProcessor.Imaging
}
///
- /// Gets or sets the Position of the textlayer.
+ /// Gets or sets the Position of the text layer.
///
public Point Position
{
@@ -75,7 +84,10 @@ namespace ImageProcessor.Imaging
}
///
- /// Gets or sets the FontStyle of the textlayer.
+ /// Gets or sets the FontStyle of the text layer.
+ ///
+ /// Defaults to regular.
+ ///
///
public FontStyle Style